Utilities
=========

Application Mapping
-------------------

.. autoclass:: pancad.abstract.PancadThing
    :show-inheritance:
    :members:

Exceptions
----------

.. autoclass:: pancad.exceptions.DupeUidError
    :show-inheritance:

.. autoclass:: pancad.exceptions.DupeNameError
    :show-inheritance:

.. autoclass:: pancad.exceptions.HasDependentsError
    :show-inheritance:

.. autoclass:: pancad.exceptions.SketchDupeUidError
    :show-inheritance:

.. autoclass:: pancad.exceptions.MissingCADDependencyError
    :show-inheritance:

.. autoclass:: pancad.exceptions.SketchGeometryHasConstraintsError
    :show-inheritance:

Trigonometry
------------

.. automodule:: pancad.utils.trigonometry
    :members:
